Statically analyzes the application's Parapet configuration and exposes a runtime-oriented
cluster mode for live facts.
Statuses:
info: informational or healthywarn: risk or ambiguity that should fail CI when threshold iswarnerror: concrete contradiction or unsafe setupskip: check not applicable or unavailable
Exit codes:
0: no findings at or above the active threshold1: at least one finding at or above the active threshold2: doctor execution failed or a runtime probe could not run