Provides flap protection by short-circuiting automated runbook execution if it loops excessively.
Experimental
This module is experimental in v1.x. Its API may change in a minor release with a single-version notice in CHANGELOG.md. See Stability & Deprecation Policy for details.
Summary
Functions
Checks if a given step for an incident is allowed to execute based on historical tool audit records within the configured time window.
Functions
Checks if a given step for an incident is allowed to execute based on historical tool audit records within the configured time window.