Parapet.Integrations.Threadline (parapet v1.0.0)

Copy Markdown View Source

Parapet integration for the Threadline audit library. Maps audit data between Threadline and Parapet.

Experimental

This module is experimental in v1.x. Its API may change in a minor release with a single-version notice in CHANGELOG.md. See Stability & Deprecation Policy for details.

Summary

Functions

Handles telemetry events safely.

Attaches telemetry handlers for Threadline audit events and Parapet audit events.

Safely translates Parapet.Spine.ToolAudit or a map to Threadline schema shapes.

Functions

handle_event(event, measurements, metadata, config)

Handles telemetry events safely.

setup()

Attaches telemetry handlers for Threadline audit events and Parapet audit events.

to_threadline_shape(audit)

Safely translates Parapet.Spine.ToolAudit or a map to Threadline schema shapes.