Parapet.MCP.PrometheusClient (parapet v1.0.0)

Copy Markdown View Source

A read-only Prometheus HTTP API proxy using Req to allow external agents to retrieve predefined time-series metrics.

Experimental

This module is experimental in v1.x. Its API may change in a minor release with a single-version notice in CHANGELOG.md. See Stability & Deprecation Policy for details.

Summary

Functions

Fetches the SLO burn rate for a given SLO name using a hardcoded, safe PromQL query. Returns the parsed Prometheus API response.

Functions

get_slo_burn_rate(name, opts \\ [])

Fetches the SLO burn rate for a given SLO name using a hardcoded, safe PromQL query. Returns the parsed Prometheus API response.

Options:

  • :req_options - additional options to pass to Req.request/1 (e.g. for testing)