An ETS-backed store for holding the latest trace ID associated with a metric and its tags. This allows Prometheus formatters to quickly fetch the recent trace exemplar.
Experimental
This module is experimental in v1.x. Its API may change in a minor release with a single-version notice in CHANGELOG.md. See Stability & Deprecation Policy for details.
Summary
Functions
Returns a specification to start this module under a supervisor.