Parapet.Metrics.Probe (parapet v1.0.0)

Copy Markdown View Source

Defines Prometheus distributions and counters for synthetic probes.

Experimental

This module is experimental in v1.x. Its API may change in a minor release with a single-version notice in CHANGELOG.md. See Stability & Deprecation Policy for details.

Summary

Functions

Defines the metrics for the telemetry events.

Sets up the Probe metrics by attaching telemetry handlers.

Functions

metrics()

Defines the metrics for the telemetry events.

setup()

Sets up the Probe metrics by attaching telemetry handlers.