Parapet.Probe.NativeScheduler (parapet v1.0.0)

Copy Markdown View Source

A simple GenServer-based scheduler for executing synthetic probes.

It uses :timer.send_interval/2 to periodically trigger probe executions. Useful for standalone or non-clustered setups.

Experimental

This module is experimental in v1.x. Its API may change in a minor release with a single-version notice in CHANGELOG.md. See Stability & Deprecation Policy for details.

Summary

Functions

Returns a specification to start this module under a supervisor.

Starts the NativeScheduler.

Functions

child_spec(init_arg)

Returns a specification to start this module under a supervisor.

See Supervisor.

start_link(probes)

Starts the NativeScheduler.

Options

The first argument should be a list of probes and their intervals in milliseconds. For example: [{MyProbe, 60_000}]