Parapet.Probe.ObanScheduler (parapet v1.0.0)

Copy Markdown View Source

Optional Oban worker for scheduling synthetic probes without retries.

Experimental

This module is experimental in v1.x. Its API may change in a minor release with a single-version notice in CHANGELOG.md. See Stability & Deprecation Policy for details.