Parapet.Spine.AlertProcessor (parapet v1.0.0)

Copy Markdown View Source

Processes alert batches received from webhooks.

Experimental

This module is experimental in v1.x. Its API may change in a minor release with a single-version notice in CHANGELOG.md. See Stability & Deprecation Policy for details.

Summary

Functions

Processes a batch of alerts from the webhook payload.

Functions

process_batch(payload)

Processes a batch of alerts from the webhook payload.