Parapet integration for the Scoria AI library. Listens to Scoria telemetry events and translates them into Parapet metrics while stripping high-cardinality metadata and creating incidents for severe errors.
Experimental
This module is experimental in v1.x. Its API may change in a minor release with a single-version notice in CHANGELOG.md. See Stability & Deprecation Policy for details.
Summary
Functions
Checks the external Scoria workflow state and conditionally resolves the action item if the workflow is no longer paused.
Handles Scoria telemetry events, translates them to Parapet metrics, and logs incidents for AI tool failures.
Attaches telemetry handlers for Scoria events.
Functions
Checks the external Scoria workflow state and conditionally resolves the action item if the workflow is no longer paused.
Handles Scoria telemetry events, translates them to Parapet metrics, and logs incidents for AI tool failures.
Attaches telemetry handlers for Scoria events.